# Installation

## Stable release

To install U_2ls, run this command in your terminal:

```sh
uv add U_2ls
```

Or if you prefer to use `pip`:

```sh
pip install U_2ls
```

## From source

The source files for U_2ls can be downloaded from the [Github repo](https://github.com/rveverbr-private/U_2ls).

You can either clone the public repository:

```sh
git clone git://github.com/rveverbr-private/U_2ls
```

Or download the [tarball](https://github.com/rveverbr-private/U_2ls/tarball/master):

```sh
curl -OJL https://github.com/rveverbr-private/U_2ls/tarball/master
```

Once you have a copy of the source, you can install it with:

```sh
cd U_2ls
uv pip install .
```
